==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/TriangulationStatusEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TriangulationStatusEventArgsDescription } from "./TriangulationStatusEventArgsDescription";
/**
 * @hidden
 */
export let TriangulationStatusEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class TriangulationStatusEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (TriangulationStatusEventArgsDescriptionMetadata.a == null) {
                TriangulationStatusEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TriangulationStatusEventArgsDescriptionMetadata.c(TriangulationStatusEventArgsDescriptionMetadata.a);
            }
            if (a.k(TriangulationStatusEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(TriangulationStatusEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("CurrentStatus", "Number:int");
        }
        static d(a) {
            TriangulationStatusEventArgsDescriptionMetadata.b(a);
            a.ad("TriangulationStatusEventArgs", () => new TriangulationStatusEventArgsDescription());
            a.ac("TriangulationStatusEventArgs", TriangulationStatusEventArgsDescriptionMetadata.a);
        }
    }
    TriangulationStatusEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(TriangulationStatusEventArgsDescriptionMetadata, 'TriangulationStatusEventArgsDescriptionMetadata');
    TriangulationStatusEventArgsDescriptionMetadata.a = null;
    return TriangulationStatusEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/TriangulationStatusEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TriangulationStatusEventArgsDescription } from "./TriangulationStatusEventArgsDescription";
/**
 * @hidden
 */
export let TriangulationStatusEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class TriangulationStatusEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (TriangulationStatusEventArgsDescriptionMetadata.a == null) {
                TriangulationStatusEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TriangulationStatusEventArgsDescriptionMetadata.c(TriangulationStatusEventArgsDescriptionMetadata.a);
            }
            if (a.k(TriangulationStatusEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(TriangulationStatusEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("CurrentStatus", "Number:int");
        }
        static d(a) {
            TriangulationStatusEventArgsDescriptionMetadata.b(a);
            a.ae("TriangulationStatusEventArgs", () => new TriangulationStatusEventArgsDescription());
            a.ad("TriangulationStatusEventArgs", TriangulationStatusEventArgsDescriptionMetadata.a);
        }
    }
    TriangulationStatusEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(TriangulationStatusEventArgsDescriptionMetadata, 'TriangulationStatusEventArgsDescriptionMetadata');
    TriangulationStatusEventArgsDescriptionMetadata.a = null;
    return TriangulationStatusEventArgsDescriptionMetadata;
})();
